@@ -18,7 +18,7 @@ import warnings
 
 import numpy as np
 import pytensor
-import pytensor.tensor as at
+import pytensor.tensor as pt
 import pytest
 import scipy.special as sp
 import scipy.stats as st
@@ -29,8 +29,7 @@ from pytensor.tensor import TensorVariable
 import pymc as pm
 
 from pymc.distributions.discrete import Geometric, _OrderedLogistic, _OrderedProbit
-from pymc.logprob.abstract import logcdf
-from pymc.logprob.joint_logprob import logp
+from pymc.logprob.basic import icdf, logcdf, logp
 from pymc.logprob.utils import ParameterValueError
 from pymc.pytensorf import floatX
 from pymc.testing import (
@@ -118,6 +117,12 @@ class TestMatchesScipy:
             Domain([-10, 0, 10], "int64"),
             {"lower": -Rplusdunif, "upper": Rplusdunif},
         )
+        check_icdf(
+            pm.DiscreteUniform,
+            {"lower": -Rplusdunif, "upper": Rplusdunif},
+            lambda q, lower, upper: st.randint.ppf(q=q, low=lower, high=upper + 1),
+            skip_paramdomain_outside_edge_test=True,
+        )
         # Custom logp / logcdf check for invalid parameters
         invalid_dist = pm.DiscreteUniform.dist(lower=1, upper=0)
         with pytensor.config.change_flags(mode=Mode("py")):
@@ -125,6 +130,8 @@ class TestMatchesScipy:
                 logp(invalid_dist, 0.5).eval()
             with pytest.raises(ParameterValueError):
                 logcdf(invalid_dist, 2).eval()
+            with pytest.raises(ParameterValueError):
+                icdf(invalid_dist, np.array(1)).eval()
 
     def test_geometric(self):
         check_logp(
@@ -502,7 +509,7 @@ class TestMatchesScipy:
             # entries if there is a single or pair number of negative values
             # and the rest are zero
             np.array([-1, -1, 0, 0]),
-            at.as_tensor_variable([-1, -1, 0, 0]),
+            pt.as_tensor_variable([-1, -1, 0, 0]),
         ],
     )
     def test_categorical_negative_p(self, p):
@@ -521,7 +528,7 @@ class TestMatchesScipy:
     def test_categorical_negative_p_symbolic(self):
         value = np.array([[1, 1, 1]])
 
-        x = at.scalar("x")
+        x = pt.scalar("x")
         invalid_dist = pm.Categorical.dist(p=[x, x, x])
 
         with pytest.raises(ParameterValueError):
@@ -530,7 +537,7 @@ class TestMatchesScipy:
     def test_categorical_p_not_normalized_symbolic(self):
         value = np.array([[1, 1, 1]])
 
-        x = at.scalar("x")
+        x = pt.scalar("x")
         invalid_dist = pm.Categorical.dist(p=(x, x, x))
 
         with pytest.raises(ParameterValueError):
