@@ -36,16 +36,18 @@
 
 import numpy as np
 import pytensor
-import pytensor.tensor as at
+import pytensor.tensor as pt
 import pytest
 import scipy.stats.distributions as sp
 
+from pytensor import function
 from pytensor.graph.basic import Variable, equal_computations
+from pytensor.ifelse import ifelse
 from pytensor.tensor.random.basic import CategoricalRV
 from pytensor.tensor.shape import shape_tuple
 from pytensor.tensor.subtensor import as_index_constant
 
-from pymc.logprob.joint_logprob import factorized_joint_logprob
+from pymc.logprob.basic import factorized_joint_logprob
 from pymc.logprob.mixture import MixtureRV, expand_indices
 from pymc.logprob.rewriting import construct_ir_fgraph
 from pymc.logprob.utils import dirac_delta
@@ -54,13 +56,13 @@ from tests.logprob.utils import joint_logprob, scipy_logprob
 
 
 def test_mixture_basics():
-    srng = at.random.RandomStream(29833)
+    srng = pt.random.RandomStream(29833)
 
     def create_mix_model(size, axis):
         X_rv = srng.normal(0, 1, size=size, name="X")
         Y_rv = srng.gamma(0.5, 0.5, size=size, name="Y")
 
-        p_at = at.scalar("p")
+        p_at = pt.scalar("p")
         p_at.tag.test_value = 0.5
 
         I_rv = srng.bernoulli(p_at, size=size, name="I")
@@ -68,9 +70,9 @@ def test_mixture_basics():
         i_vv.name = "i"
 
         if isinstance(axis, Variable):
-            M_rv = at.join(axis, X_rv, Y_rv)[I_rv]
+            M_rv = pt.join(axis, X_rv, Y_rv)[I_rv]
         else:
-            M_rv = at.stack([X_rv, Y_rv], axis=axis)[I_rv]
+            M_rv = pt.stack([X_rv, Y_rv], axis=axis)[I_rv]
 
         M_rv.name = "M"
         m_vv = M_rv.clone()
@@ -92,7 +94,7 @@ def test_mixture_basics():
         factorized_joint_logprob({M_rv: m_vv, I_rv: i_vv, X_rv: x_vv})
 
     with pytest.raises(RuntimeError, match="could not be derived: {m}"):
-        axis_at = at.lscalar("axis")
+        axis_at = pt.lscalar("axis")
         axis_at.tag.test_value = 0
         env = create_mix_model((2,), axis_at)
         I_rv = env["I_rv"]
@@ -106,17 +108,17 @@ def test_mixture_basics():
 @pytest.mark.parametrize(
     "op_constructor",
     [
-        lambda _I, _X, _Y: at.stack([_X, _Y])[_I],
-        lambda _I, _X, _Y: at.switch(_I, _X, _Y),
+        lambda _I, _X, _Y: pt.stack([_X, _Y])[_I],
+        lambda _I, _X, _Y: pt.switch(_I, _X, _Y),
     ],
 )
 def test_compute_test_value(op_constructor):
-    srng = at.random.RandomStream(29833)
+    srng = pt.random.RandomStream(29833)
 
     X_rv = srng.normal(0, 1, name="X")
     Y_rv = srng.gamma(0.5, 0.5, name="Y")
 
-    p_at = at.scalar("p")
+    p_at = pt.scalar("p")
     p_at.tag.test_value = 0.3
 
     I_rv = srng.bernoulli(p_at, name="I")
@@ -151,18 +153,18 @@ def test_compute_test_value(op_constructor):
     ],
 )
 def test_hetero_mixture_binomial(p_val, size, supported):
-    srng = at.random.RandomStream(29833)
+    srng = pt.random.RandomStream(29833)
 
     X_rv = srng.normal(0, 1, size=size, name="X")
     Y_rv = srng.gamma(0.5, 0.5, size=size, name="Y")
 
     if np.ndim(p_val) == 0:
-        p_at = at.scalar("p")
+        p_at = pt.scalar("p")
         p_at.tag.test_value = p_val
         I_rv = srng.bernoulli(p_at, size=size, name="I")
         p_val_1 = p_val
     else:
-        p_at = at.vector("p")
+        p_at = pt.vector("p")
         p_at.tag.test_value = np.array(p_val, dtype=pytensor.config.floatX)
         I_rv = srng.categorical(p_at, size=size, name="I")
         p_val_1 = p_val[1]
@@ -170,7 +172,7 @@ def test_hetero_mixture_binomial(p_val, size, supported):
     i_vv = I_rv.clone()
     i_vv.name = "i"
 
-    M_rv = at.stack([X_rv, Y_rv])[I_rv]
+    M_rv = pt.stack([X_rv, Y_rv])[I_rv]
     M_rv.name = "M"
 
     m_vv = M_rv.clone()
@@ -560,13 +562,13 @@ def test_hetero_mixture_binomial(p_val, size, supported):
 def test_hetero_mixture_categorical(
     X_args, Y_args, Z_args, p_val, comp_size, idx_size, extra_indices, join_axis, supported
 ):
-    srng = at.random.RandomStream(29833)
+    srng = pt.random.RandomStream(29833)
 
     X_rv = srng.normal(*X_args, size=comp_size, name="X")
     Y_rv = srng.gamma(*Y_args, size=comp_size, name="Y")
     Z_rv = srng.normal(*Z_args, size=comp_size, name="Z")
 
-    p_at = at.as_tensor(p_val).type()
+    p_at = pt.as_tensor(p_val).type()
     p_at.name = "p"
     p_at.tag.test_value = np.array(p_val, dtype=pytensor.config.floatX)
     I_rv = srng.categorical(p_at, size=idx_size, name="I")
@@ -578,7 +580,7 @@ def test_hetero_mixture_categorical(
     indices_at.insert(join_axis, I_rv)
     indices_at = tuple(indices_at)
 
-    M_rv = at.stack([X_rv, Y_rv, Z_rv], axis=join_axis)[indices_at]
+    M_rv = pt.stack([X_rv, Y_rv, Z_rv], axis=join_axis)[indices_at]
     M_rv.name = "M"
 
     m_vv = M_rv.clone()
@@ -727,7 +729,7 @@ def test_hetero_mixture_categorical(
     ],
 )
 def test_expand_indices_basic(A_parts, indices):
-    A = at.stack(A_parts)
+    A = pt.stack(A_parts)
     at_indices = [as_index_constant(idx) for idx in indices]
     full_indices = expand_indices(at_indices, shape_tuple(A))
     assert len(full_indices) == A.ndim
@@ -764,7 +766,7 @@ def test_expand_indices_basic(A_parts, indices):
     ],
 )
 def test_expand_indices_moved_subspaces(A_parts, indices):
-    A = at.stack(A_parts)
+    A = pt.stack(A_parts)
     at_indices = [as_index_constant(idx) for idx in indices]
     full_indices = expand_indices(at_indices, shape_tuple(A))
     assert len(full_indices) == A.ndim
@@ -811,7 +813,7 @@ def test_expand_indices_moved_subspaces(A_parts, indices):
     ],
 )
 def test_expand_indices_single_indices(A_parts, indices):
-    A = at.stack(A_parts)
+    A = pt.stack(A_parts)
     at_indices = [as_index_constant(idx) for idx in indices]
     full_indices = expand_indices(at_indices, shape_tuple(A))
     assert len(full_indices) == A.ndim
@@ -866,7 +868,7 @@ def test_expand_indices_single_indices(A_parts, indices):
     ],
 )
 def test_expand_indices_newaxis(A_parts, indices):
-    A = at.stack(A_parts)
+    A = pt.stack(A_parts)
     at_indices = [as_index_constant(idx) for idx in indices]
     full_indices = expand_indices(at_indices, shape_tuple(A))
     assert len(full_indices) == A.ndim
@@ -876,7 +878,7 @@ def test_expand_indices_newaxis(A_parts, indices):
 
 
 def test_mixture_with_DiracDelta():
-    srng = at.random.RandomStream(29833)
+    srng = pt.random.RandomStream(29833)
 
     X_rv = srng.normal(0, 1, name="X")
     Y_rv = dirac_delta(0.0)
@@ -887,7 +889,7 @@ def test_mixture_with_DiracDelta():
     i_vv = I_rv.clone()
     i_vv.name = "i"
 
-    M_rv = at.stack([X_rv, Y_rv])[I_rv]
+    M_rv = pt.stack([X_rv, Y_rv])[I_rv]
     M_rv.name = "M"
 
     m_vv = M_rv.clone()
@@ -899,7 +901,7 @@ def test_mixture_with_DiracDelta():
 
 
 def test_switch_mixture():
-    srng = at.random.RandomStream(29833)
+    srng = pt.random.RandomStream(29833)
 
     X_rv = srng.normal(-10.0, 0.1, name="X")
     Y_rv = srng.normal(10.0, 0.1, name="Y")
@@ -908,7 +910,7 @@ def test_switch_mixture():
     i_vv = I_rv.clone()
     i_vv.name = "i"
 
-    Z1_rv = at.switch(I_rv, X_rv, Y_rv)
+    Z1_rv = pt.switch(I_rv, X_rv, Y_rv)
     z_vv = Z1_rv.clone()
     z_vv.name = "z1"
 
@@ -928,7 +930,7 @@ def test_switch_mixture():
 
     # building the identical graph but with a stack to check that mixture computations are identical
 
-    Z2_rv = at.stack((X_rv, Y_rv))[I_rv]
+    Z2_rv = pt.stack((X_rv, Y_rv))[I_rv]
 
     fgraph2, _, _ = construct_ir_fgraph({Z2_rv: z_vv, I_rv: i_vv})
 
@@ -942,3 +944,109 @@ def test_switch_mixture():
 
     np.testing.assert_almost_equal(0.69049938, z1_logp.eval({z_vv: -10, i_vv: 0}))
     np.testing.assert_almost_equal(0.69049938, z2_logp.eval({z_vv: -10, i_vv: 0}))
+
+
+def test_ifelse_mixture_one_component():
+    if_rv = pt.random.bernoulli(0.5, name="if")
+    scale_rv = pt.random.halfnormal(name="scale")
+    comp_then = pt.random.normal(0, scale_rv, size=(2,), name="comp_then")
+    comp_else = pt.random.halfnormal(0, scale_rv, size=(4,), name="comp_else")
+    mix_rv = ifelse(if_rv, comp_then, comp_else, name="mix")
+
+    if_vv = if_rv.clone()
+    scale_vv = scale_rv.clone()
+    mix_vv = mix_rv.clone()
+    mix_logp = factorized_joint_logprob({if_rv: if_vv, scale_rv: scale_vv, mix_rv: mix_vv})[mix_vv]
+    assert_no_rvs(mix_logp)
+
+    fn = function([if_vv, scale_vv, mix_vv], mix_logp)
+    scale_vv_test = 0.75
+    mix_vv_test = np.r_[1.0, 2.5]
+    np.testing.assert_array_almost_equal(
+        fn(1, scale_vv_test, mix_vv_test),
+        sp.norm(0, scale_vv_test).logpdf(mix_vv_test),
+    )
+    mix_vv_test = np.r_[1.0, 2.5, 3.5, 4.0]
+    np.testing.assert_array_almost_equal(
+        fn(0, scale_vv_test, mix_vv_test), sp.halfnorm(0, scale_vv_test).logpdf(mix_vv_test)
+    )
+
+
+def test_ifelse_mixture_multiple_components():
+    rng = np.random.default_rng(968)
+
+    if_var = pt.scalar("if_var", dtype="bool")
+    comp_then1 = pt.random.normal(size=(2,), name="comp_true1")
+    comp_then2 = pt.random.normal(comp_then1, size=(2, 2), name="comp_then2")
+    comp_else1 = pt.random.halfnormal(size=(4,), name="comp_else1")
+    comp_else2 = pt.random.halfnormal(size=(4, 4), name="comp_else2")
+
+    mix_rv1, mix_rv2 = ifelse(
+        if_var, [comp_then1, comp_then2], [comp_else1, comp_else2], name="mix"
+    )
+    mix_vv1 = mix_rv1.clone()
+    mix_vv2 = mix_rv2.clone()
+    mix_logp1, mix_logp2 = factorized_joint_logprob({mix_rv1: mix_vv1, mix_rv2: mix_vv2}).values()
+    assert_no_rvs(mix_logp1)
+    assert_no_rvs(mix_logp2)
+
+    fn = function([if_var, mix_vv1, mix_vv2], mix_logp1.sum() + mix_logp2.sum())
+    mix_vv1_test = np.abs(rng.normal(size=(2,)))
+    mix_vv2_test = np.abs(rng.normal(size=(2, 2)))
+    np.testing.assert_almost_equal(
+        fn(True, mix_vv1_test, mix_vv2_test),
+        sp.norm(0, 1).logpdf(mix_vv1_test).sum()
+        + sp.norm(mix_vv1_test, 1).logpdf(mix_vv2_test).sum(),
+    )
+    mix_vv1_test = np.abs(rng.normal(size=(4,)))
+    mix_vv2_test = np.abs(rng.normal(size=(4, 4)))
+    np.testing.assert_almost_equal(
+        fn(False, mix_vv1_test, mix_vv2_test),
+        sp.halfnorm(0, 1).logpdf(mix_vv1_test).sum() + sp.halfnorm(0, 1).logpdf(mix_vv2_test).sum(),
+    )
+
+
+def test_ifelse_mixture_shared_component():
+    rng = np.random.default_rng(1009)
+
+    if_var = pt.scalar("if_var", dtype="bool")
+    outer_rv = pt.random.normal(name="outer")
+    # comp_shared need not be an output of ifelse at all,
+    # but since we allow arbitrary graphs we test it works as expected.
+    comp_shared = pt.random.normal(size=(2,), name="comp_shared")
+    comp_then = outer_rv + pt.random.normal(comp_shared, 1, size=(4, 2), name="comp_then")
+    comp_else = outer_rv + pt.random.normal(comp_shared, 10, size=(8, 2), name="comp_else")
+    shared_rv, mix_rv = ifelse(
+        if_var, [comp_shared, comp_then], [comp_shared, comp_else], name="mix"
+    )
+
+    outer_vv = outer_rv.clone()
+    shared_vv = shared_rv.clone()
+    mix_vv = mix_rv.clone()
+    outer_logp, mix_logp1, mix_logp2 = factorized_joint_logprob(
+        {outer_rv: outer_vv, shared_rv: shared_vv, mix_rv: mix_vv}
+    ).values()
+    assert_no_rvs(outer_logp)
+    assert_no_rvs(mix_logp1)
+    assert_no_rvs(mix_logp2)
+
+    fn = function([if_var, outer_vv, shared_vv, mix_vv], mix_logp1.sum() + mix_logp2.sum())
+    outer_vv_test = rng.normal()
+    shared_vv_test = rng.normal(size=(2,))
+    mix_vv_test = rng.normal(size=(4, 2))
+    np.testing.assert_almost_equal(
+        fn(True, outer_vv_test, shared_vv_test, mix_vv_test),
+        (
+            sp.norm(0, 1).logpdf(shared_vv_test).sum()
+            + sp.norm(outer_vv_test + shared_vv_test, 1).logpdf(mix_vv_test).sum()
+        ),
+    )
+    mix_vv_test = rng.normal(size=(8, 2))
+    np.testing.assert_almost_equal(
+        fn(False, outer_vv_test, shared_vv_test, mix_vv_test),
+        (
+            sp.norm(0, 1).logpdf(shared_vv_test).sum()
+            + sp.norm(outer_vv_test + shared_vv_test, 10).logpdf(mix_vv_test).sum()
+        ),
+        decimal=6,
+    )
